@@ -1,8 +1,10 @@
 from defichainUtils.utils import ParamType
 from defichainUtils.utils import utils,CustomTxDecode
+import defichainUtils.utils.chain as chain
 from defichainUtils.utils import CustomTx
 # from utils import ParamType
-# from utils import utils,CustomTxDecode
+# from utils import utils,CustomTxDecode,
+# import utils.chain as chain
 # from utils import CustomTx
 from dataclasses import dataclass
 
@@ -105,7 +107,48 @@ def decodeCustomTx(hex:str):
         }
     return CustomTxDecode.decodeCustomTx(hex[8:])
 
-    
+def processCustomTransactionOnChain(block,name,parameters:dict,pool:dict):
+    '''
+    block: blockHeight
+    name: Name of the rpc function (lowercase), e.g. poolswap (compositeswap is a chain of poolswaps!!! Act accordingly. Only poolswap possible)
+    parameters: key value pair of rpc parameters. 
+    pool: pool parameters - reserveA, reserveB, totalLiquidity, poolSymbol (e.g. TSLA-DUSD)
+
+    RETURN:
+    addpoolliquidity: amount liquidity tokens
+    removepoolliquidity: amount of TokenA and TokenB (tuple)
+    poolswap: amount of new reserveA, new reserveB and amount TokenB (tuple)
+    '''
+    if 'reserveA' not in pool or 'reserveB' not in pool:
+        # TODO: Raise Error
+        return {
+            'error': 1,
+            'msg': 'reserveA and/or reserveB missing'
+        }
+    if name == 'addpoolliquidity':
+        if 'amountA' not in parameters or 'amountB' not in parameters or 'totalLiquidity' not in pool:
+            # TODO: Raise Error
+            return {
+                'error': 1,
+                'msg': 'amountA and/or amountB and/or totalLiquidity missing'
+            } 
+        return chain.addPoolLiquidity(parameters['amountA'],parameters['amountB'],pool['reserveA'],pool['reserveB'],pool['totalLiquidity'])
+    elif name == 'removepoolliquidity':
+        if 'liquidity' not in parameters or 'totalLiquidity' not in pool:
+            # TODO: Raise Error
+            return {
+                'error': 1,
+                'msg': 'liquidity and/or totalLiquidity missing'
+            } 
+        return chain.removePoolLiquidity(parameters['liquidity'],pool['reserveA'],pool['reserveB'],pool['totalLiquidity'])
+    elif name == 'poolswap':
+        if 'tokenFrom' not in parameters or 'fromAmount' not in parameters or 'symbol' not in pool or 'commission' not in parameters or 'dexFeeInPct' not in parameters:
+            # TODO: Raise Error
+            return {
+                'error': 1,
+                'msg': 'tokenFrom and/or fromAmount and/or symbol and/or commission and/or dexFeeInPct missing'
+            } 
+        return chain.poolSwap(block,parameters['tokenFrom'],pool['symbol'],parameters['fromAmount'],pool['reserveA'],pool['reserveB'],parameters['commission'],parameters['dexFeeInPct'])
 
 # TODO: only working in python3.9 not in 3.8!!!
 # class TakeLoan(CustomTx.DfTx):
