@@ -58,7 +58,7 @@ def decodeSetGovVariableHeight(hex):
         #     }
         variables = [
             {'key':'attributes', 'type': [
-                {'bytesCount': 4, 'key': None, 'type': int,'endian':None},
+                {'bytesCount': 4, 'key': 'unknown', 'type': int,'endian':None},
                 {'bytesCount': 1, 'key': 'type', 'type': str,'endian':None},
                 {'bytesCount': 1, 'key': 'typeId', 'type': int,'endian':None},
                 {'bytesCount': 4, 'key': 'key', 'type': str,'endian':'big'},
@@ -129,8 +129,8 @@ def decodeRemovePoolLiquidity(hex):
     return searchHex(variables,hex)
 def decodeCreatePoolPair(hex):
     variables = [
-        {'bytesCount':1, 'key': 'tokenId', 'type': int,'endian':None},
-        {'bytesCount':1, 'key': 'tokenId', 'type': int,'endian':None},
+        {'bytesCount':1, 'key': 'tokenIdA', 'type': int,'endian':None},
+        {'bytesCount':1, 'key': 'tokenIdB', 'type': int,'endian':None},
         {'bytesCount': 8, 'key': 'commission', 'type': int,'endian':'big'},
         {'key': 'from', 'type': 'address','endian':None},
         {'bytesCount':1, 'key': 'status', 'type': int,'endian':None}
